/*   FILE: playlist.h -- Playlist support
 * AUTHOR: W. Michael Petullo <mike@flyn.org>
 *   DATE: 12 February 2022
 *
 * Copyright (c) 2022 W. Michael Petullo <new@flyn.org>
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _PLAYLIST_H
#define _PLAYLIST_H

#include <libdmapsharing/dmap.h>

void playlist_add_playlists(gchar **playlist_dirs, DmapDb *db, DmapContainerDb *container_db);

#endif
